PR #22948 opened by Marvin Scholz (ePirat)
URL: https://code.ffmpeg.org/FFmpeg/FFmpeg/pulls/22948
Patch URL: https://code.ffmpeg.org/FFmpeg/FFmpeg/pulls/22948.patch

This avoids conflicts with the C++ version header.

Fix #22574


>From 33100391fe415df9622d01520390890ba5919d98 Mon Sep 17 00:00:00 2001
From: Marvin Scholz <[email protected]>
Date: Tue, 28 Apr 2026 15:31:17 +0200
Subject: [PATCH] ffbuild/version.sh: rename VERSION file to FF_VERSION

This avoids conflicts with the C++ version header.

Fix #22574
---
 ffbuild/version.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/ffbuild/version.sh b/ffbuild/version.sh
index edc4dd33c5..1c6f70ba21 100755
--- a/ffbuild/version.sh
+++ b/ffbuild/version.sh
@@ -34,8 +34,8 @@ test "$revision" || revision=$(cd "$1" && cat RELEASE 2> 
/dev/null)
 # Append the Git hash if we have one
 test "$revision" && test "$git_hash" && revision="$revision-$git_hash"
 
-# releases extract the version number from the VERSION file
-version=$(cd "$1" && cat VERSION 2> /dev/null)
+# releases extract the version number from the FF_VERSION file
+version=$(cd "$1" && cat FF_VERSION 2> /dev/null)
 test "$version" || version=$revision
 
 test -n "$3" && version=$version-$3
-- 
2.52.0

_______________________________________________
ffmpeg-devel mailing list -- [email protected]
To unsubscribe send an email to [email protected]

Reply via email to